pyDataCanvas
============

Runtime support for DataCanvas

Installation
------------

Our latest stable is always available on PyPi.

    pip install pyDataCanvas

Documentation
-------------

See also [screwjack](screwjack.readthedocs.org).

License
-------
pyDataCanvas is licensed under the Apache License, Version 2.0. See LICENSE for full license text

